View source: R/download_maca.R
| download_maca | R Documentation |
Download MACA climate data from kamiak
download_maca( location, data_folder, kamiak_user_name, models = agclimtools::maca_models, climate_proj = agclimtools::climate_projections )
location |
file name of location to download in format "data_lat_long" |
data_folder |
path to local folder to store downloaded data |
kamiak_user_name |
username used to access kamiak ex. "user.name" |
models |
list of models to download defaults to all models |
climate_proj |
list of climate projections to download (historical, rcp45, rcp85) |
## Not run: download_maca("data_36.65625_-121.65625", "data", "matthew.pruett")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.